@@ -1,11 +1,13 @@
 Qt.include("utils.js")
 
+var API_VERSION = "20120910";
 var CLIENT_ID = "4IFSW3ZXR4BRBXT3IIZMB13YPNGSIOK4ANEM0PP3T2CQQFWI";
 var CALLBACK_URL = "http://nelisquare.substanceofcode.com/callback.php";
 var AUTHENTICATE_URL = "https://foursquare.com/oauth2/authenticate" +
     "?client_id=" + CLIENT_ID +
     "&response_type=token" +
     "&display=touch" +
+    "&v=" + API_VERSION +
     "&redirect_uri=" + CALLBACK_URL;
 
 var accessToken = "";
@@ -69,11 +71,11 @@ function parseAuth(data, parameterName) {
 }
 
 function getAccessTokenParameter() {
-    return "oauth_token=" + accessToken;
+    return "oauth_token=" + accessToken+"&v="+API_VERSION;
 }
 
 function showError(msg) {
-    waiting.state = "hidden";
+    waiting.hide();
     console.log("Error: "+ msg);
     //error.state = "shown";
     //error.reason = msg;
@@ -96,11 +98,11 @@ function parseToken(data) {
     logo.state = "hidden"; //.visible = false;
     if(sid.length>0) {
         navigation.state = "menu";
-        waiting.state = "hidden";
+        waiting.hide();
         //loadUnreadNews();
     } else {
         addError("Couldn't parse SID");
-        waiting.state = "hidden";
+        waiting.hide();
     }
 }
 
@@ -126,7 +128,7 @@ function showDone(data) {
     if(waiting.state!="shown") {
         return;
     }
-    waiting.state = "hidden";
+    waiting.hide();
     done.status = "";
     if(typeof(data)!="undefined" && data!=null) {
         if(action=="read") {
@@ -149,15 +151,19 @@ function makeUserName(user) {
     return username;
 }
 
-function thumbnailPhoto(photos, minsize) {
+function thumbnailPhoto(photo, width_, height_) {
     var url = "";
-    var width = 1000;
-    photos.sizes.items.forEach(function(photo) {
-        if (photo.width < width && photo.width >= minsize ) {
-            width = photo.width;
-            url = photo.url;
-        }
-    });
+    var width = photo.width;
+    var height = photo.height;
+    if (width_ !== undefined)
+        width = width_;
+    if (height_ !== undefined)
+        height = height_;
+    if (width === undefined)
+        width = 100;
+    if (height === undefined)
+        height = width
+    url = photo.prefix + width+"x"+height + photo.suffix;
     return url;
 }
 
@@ -189,7 +195,7 @@ function addTipToModel(tip) {
     //console.log("VENUE TIP: " + JSON.stringify(tip));
     venueDetails.tipsModel.append({
                      "userID": tip.user.id,
-                     "userPhoto": tip.user.photo,
+                     "userPhoto": thumbnailPhoto(tip.user.photo,100),
                      "tipID": tip.id,
                      "tipText": tip.text,
                      "tipAge": "Added " + makeTime(tip.createdAt)
@@ -201,7 +207,7 @@ function addCommentToModel(comment) {
     var createdAgo = makeTime(comment.createdAt);
     var userID = comment.user.id;
     var userName = makeUserName(comment.user);
-    var userPhoto = comment.user.photo;
+    var userPhoto = thumbnailPhoto(comment.user.photo,100);
     var text = comment.text;
     var relationship = parse(comment.user.relationship);
 
@@ -216,20 +222,20 @@ function addCommentToModel(comment) {
                          });
 }
 
-function loadFriendsCheckins() {
+function loadFriendsFeed() {
     var url = "checkins/recent?" + getAccessTokenParameter();
-    doWebRequest("GET", url, "", parseFriendsCheckins);
-    waiting.state = "shown";
+    doWebRequest("GET", url, "", parseFriendsFeed);
+    waiting.show();
 }
 
-function loadNearbyFriendsCheckins() {
+function loadFriendsFeedNearby() {
     var url = "checkins/recent?" +
         getLocationParameter() + "&" + getAccessTokenParameter();
-    doWebRequest("GET", url, "", parseFriendsCheckins);
-    waiting.state = "shown";
+    doWebRequest("GET", url, "", parseFriendsFeed);
+    waiting.show();
 }
 
-function parseFriendsCheckins(response) {
+function parseFriendsFeed(response) {
     var data = processResponse(response);
     var count = 0;
     friendsCheckinsModel.clear();
@@ -243,9 +249,9 @@ function parseFriendsCheckins(response) {
             venueName = checkin.venue.name;
             venueID = checkin.venue.id;
         }
-        var comments = 0;
+        var likes = 0;
         if (typeof(checkin.comments)!="undefined") {
-            comments = parse(checkin.comments.count);
+            likes = parse(checkin.comments.count);
         }
         var venuePhoto = "";
         if (checkin.photos.count > 0) {
@@ -257,8 +263,8 @@ function parseFriendsCheckins(response) {
                            "user": userName,
                            "userID": checkin.user.id,
                            "mayor": parse(checkin.isMayor),
-                           "photo": checkin.user.photo,
-                           "comments": comments,
+                           "photo": thumbnailPhoto(checkin.user.photo, 100),
+                           "likes": likes,
                            "venueID": venueID,
                            "venueName": venueName,
                            "createdAt": createdAgo,
@@ -266,7 +272,7 @@ function parseFriendsCheckins(response) {
         });
         count++;
     });
-    waiting.state = "hidden";
+    waiting.hide();
     if(count==0) {
         showDone("No visible checkins");
     }
@@ -286,7 +292,14 @@ function loadPlaces(query) {
     }
     url += "&" + getAccessTokenParameter();
     doWebRequest("GET", url, "", parsePlaces);
-    waiting.state = "shown";
+    waiting.show();
+}
+
+function parseIcon(icon, size) {
+    if (size === undefined) {
+        size = 32
+    }
+    return icon.prefix+"bg_"+size+icon.suffix;
 }
 
 function parse(item) {
@@ -298,15 +311,15 @@ function parse(item) {
 }
 
 function parsePlaces(response) {
-    //console.log("Response: " + response);
     var data = processResponse(response);
     var count = 0;
     placesModel.clear();
-    waiting.state = "hidden";
-    data.groups[0].items.forEach(function(place) {
+    waiting.hide();
+    data.venues.forEach(function(place) {
+        //console.log("PLACE: " + JSON.stringify(place));
         var icon = "";
         if(place.categories!=null && typeof(place.categories[0])!="undefined") {
-            icon = place.categories[0].icon;
+            icon = parseIcon(place.categories[0].icon);
         }
         placesModel.append({
                            "id": place.id,
@@ -318,8 +331,7 @@ function parsePlaces(response) {
                            "lat": place.location.lat,
                            "lng": place.location.lng,
                            "icon": icon,
-                           "venueCheckinsCount": place.stats.checkinsCount,
-                           "venueUsersCount": place.stats.usersCount
+                           "hereNow": parse(place.hereNow.count)
         });
         count++;
     });
@@ -330,7 +342,7 @@ function parsePlaces(response) {
 
 function loadVenue(venueID) {
     var url = "venues/" + venueID + "?" + getAccessTokenParameter();
-    waiting.state = "shown";
+    waiting.show();
     venueDetails.venueID = venueID;
     venueDetails.venueName = "";
     venueDetails.venueAddress = "";
@@ -348,7 +360,7 @@ function loadVenue(venueID) {
 function parseVenue(response) {
     var data = processResponse(response);
     //console.log("VENUE: "+ JSON.stringify(data));
-    waiting.state = "hidden";
+    waiting.hide();
     var venue = data.venue;
     var icon = "";
     if(venue.categories!=null && typeof(venue.categories[0])!="undefined") {
@@ -358,10 +370,11 @@ function parseVenue(response) {
     venueDetails.venueName = venue.name;
     venueDetails.venueAddress = parse(venue.location.address);
     venueDetails.venueCity = parse(venue.location.city);
-    venueDetails.venueTypeUrl = parse(venue.categories[0].icon);
+    if (venue.categories[0]!== undefined)
+        venueDetails.venueTypeUrl = parseIcon(venue.categories[0].icon);
     if(venue.mayor.count>0) {
         venueDetails.venueMajor = makeUserName(venue.mayor.user);
-        venueDetails.venueMajorPhoto = venue.mayor.user.photo;
+        venueDetails.venueMajorPhoto = thumbnailPhoto(venue.mayor.user.photo,100);
         venueDetails.venueMajorID = venue.mayor.user.id;
     }
     if(typeof(venue.location)!="undefined") {
@@ -394,7 +407,7 @@ function parseVenue(response) {
                 group.items.forEach(function(user){
                     venueDetails.usersBox.photosModel.append({
                         "objectID": user.user.id,
-                        "photoThumb": user.user.photo });
+                        "photoThumb": thumbnailPhoto(user.user.photo,100) });
                 });
             }
         });
@@ -403,7 +416,7 @@ function parseVenue(response) {
 }
 
 function addComment(checkinID, text) {
-    waiting.state = "shown";
+    waiting.show();
     var url = "checkins/" + checkinID + "/addcomment?"
     url += "CHECKIN_ID=" + checkinID + "&";
     url += "text=" + encodeURIComponent(text) + "&";
@@ -413,12 +426,12 @@ function addComment(checkinID, text) {
 
 function parseAddComment(response) {
     var data = processResponse(response);
-    waiting.state = "hidden";
+    waiting.hide();
     addCommentToModel(data.comment);
 }
 
 function deleteComment(checkinID, commentID) {
-    waiting.state = "shown";
+    waiting.show();
     var url = "checkins/" + checkinID + "/deletecomment?"
     url += "CHECKIN_ID=" + checkinID + "&";
     url += "commentId=" + commentID + "&";
@@ -428,7 +441,7 @@ function deleteComment(checkinID, commentID) {
 
 function parseDeleteComment(response) {
     var data = processResponse(response);
-    waiting.state = "hidden";
+    waiting.hide();
     commentsModel.clear();
     data.checkin.comments.items.forEach(function(comment) {
         addCommentToModel(comment);
@@ -436,7 +449,7 @@ function parseDeleteComment(response) {
 }
 
 function addTip(venueID, text) {
-    waiting.state = "shown";
+    waiting.show();
     var url = "tips/add?";
     url += "venueId=" + venueID + "&";
     url += "text=" + encodeURIComponent(text) + "&";
@@ -446,7 +459,7 @@ function addTip(venueID, text) {
 
 function parseAddTip(response){
     var data = processResponse(response);
-    waiting.state = "hidden";
+    waiting.hide();
     addTipToModel(data.tip);
 }
 
@@ -482,17 +495,17 @@ function addCheckin(venueID, comment, friends, facebook, twitter) {
     url += "&" + getAccessTokenParameter();
 
     //console.log("Checkin URL: " + url);
-    waiting.state = "shown";
+    waiting.show();
     doWebRequest("POST", url, "", parseAddCheckin);
 }
 
 function parseAddCheckin(response) {
-    //console.log("CHECKIN ===== " + response);
-    waiting.state = "hidden";
-    var data = eval("[" + response + "]")[0];
+    waiting.hide();
+    var data = processResponse(response);
     notificationDialog.message = "<span>";
     data.notifications.forEach(function(noti) {
-        if(typeof(noti.item.message)!="undefined") {
+        //console.log("NOTIFICATION: "+ JSON.stringify(noti));
+        if(noti.item.message!==undefined) {
             if(notificationDialog.message.length>6) {
                 notificationDialog.message += "<br/><br/>"
             }
@@ -501,24 +514,24 @@ function parseAddCheckin(response) {
     });
     notificationDialog.message += "</span>";
     notificationDialog.state = "shown";
-    window.showCheckinDetails(data.response.checkin.id);
+    window.showCheckinPage(data.checkin.id);
 }
 
 function loadLeaderBoard() {
     var url = "users/leaderboard?" + getAccessTokenParameter();
-    waiting.state = "shown";
+    waiting.show();
     doWebRequest("GET", url, "", parseLeaderBoard);
 }
 
 function parseLeaderBoard(response) {
-    waiting.state = "hidden";
+    waiting.hide();
     var data = eval("[" + response + "]")[0];
     boardModel.clear();
     data.response.leaderboard.items.forEach(function(ranking) {
         boardModel.append({
                            "id": ranking.user.id,
                            "name": makeUserName(ranking.user),
-                           "photo": ranking.user.photo,
+                           "photo": thumbnailPhoto(ranking.user.photo,100),
                            "recent": ranking.scores.recent,
                            "max": ranking.scores.max,
                            "checkinsCount": ranking.scores.checkinsCount,
@@ -534,19 +547,19 @@ function loadToDo() {
     var url = "users/self/todos?" +
         getLocationParameter() + "&" +
         getAccessTokenParameter();
-    waiting.state = "shown";
+    waiting.show();
     doWebRequest("GET", url, "", parseToDo);
 }
 
 function parseToDo(response) {
-    waiting.state = "hidden";
+    waiting.hide();
     var data = eval("[" + response + "]")[0];
     placesModel.clear();
     data.response.todos.items.forEach(function(todo) {
         var place = todo.tip.venue;
         var icon = "";
         if(place.categories!=null && typeof(place.categories[0])!="undefined") {
-            icon = place.categories[0].icon;
+            icon = parseIcon(place.categories[0].icon);
         }
         placesModel.append({
                            "id": place.id,
@@ -558,14 +571,13 @@ function parseToDo(response) {
                            "lat": place.location.lat,
                            "lng": place.location.lng,
                            "icon": icon,
-                           "venueCheckinsCount": place.stats.checkinsCount,
-                           "venueUsersCount": place.stats.usersCount
+                           "hereNow": ""
         });
     });
 }
 
 function loadCheckin(id) {
-    waiting.state = "shown";
+    waiting.show();
     //var id = "4fa6a2cae4b089a95b316999"; //points
     //var id = "4fa74812e4b0cbe2e15e6ada"; //bages
     //var id = "4fa6634ce4b0fd4c3fb0af77"; //points + badges
@@ -589,7 +601,7 @@ function parseCheckin(response) {
     checkinDetails.owner.userID = checkin.user.id;
     checkinDetails.owner.userName = makeUserName(checkin.user);
     checkinDetails.owner.createdAt = makeTime(checkin.createdAt);
-    checkinDetails.owner.userPhoto.photoUrl = checkin.user.photo;
+    checkinDetails.owner.userPhoto.photoUrl = thumbnailPhoto(checkin.user.photo,100);
     checkinDetails.owner.venueID = checkin.venue.id;
     checkinDetails.owner.venueName = checkin.venue.name;
     checkinDetails.owner.venueAddress = parse(checkin.venue.location.address);
@@ -625,23 +637,28 @@ function parseCheckin(response) {
         });
     }
 
-    waiting.state = "hidden";
+    waiting.hide();
 }
 
 function loadUser(user) {
     var url = "users/" + user + "?" + getAccessTokenParameter();
-    waiting.state = "shown";
+    waiting.show();
+    userDetails.boardModel.clear();
     userDetails.friendsBox.photosModel.clear();
     doWebRequest("GET", url, "", parseUser);
+    if (user == "self") {
+        url = "users/leaderboard?neighbors=2&" + getAccessTokenParameter();
+        doWebRequest("GET",url,"", parseUserBoard);
+    }
 }
 
 function parseUser(response) {
     var data = processResponse(response);
     //console.log("USER: " + JSON.stringify(data))
-    waiting.state = "hidden";
+    waiting.hide();
     var user = data.user;
     userDetails.userName = makeUserName(user);
-    userDetails.userPhoto = user.photo;
+    userDetails.userPhoto = thumbnailPhoto(user.photo,100);
     userDetails.userBadgesCount = user.badges.count;
     userDetails.userCheckinsCount = user.checkins.count;
     userDetails.userFriendsCount = user.friends.count;
@@ -661,16 +678,16 @@ function parseUser(response) {
     userDetails.userRelationship = parse(user.relationship);
 
     if (user.friends.count>0) {
-        userDetails.friendsBox.caption = "Total friends: " + user.friends.count;
+        userDetails.friendsBox.caption = "TOTAL FRIENDS: <b>" + user.friends.count +"</b>";
         user.friends.groups.forEach(function(group) {
             if (group.type == "friends") {
-                userDetails.friendsBox.caption += " ("+ group.name + " " + group.count + ")";
+                userDetails.friendsBox.caption += " ("+ group.name + " <b>" + group.count + "</b>)";
             }
             if (group.count>0) {
                 group.items.forEach(function(user){
                     userDetails.friendsBox.photosModel.append({
                         "objectID": user.id,
-                        "photoThumb": user.photo });
+                        "photoThumb": thumbnailPhoto(user.photo,100) });
                 });
             }
         });
@@ -678,8 +695,26 @@ function parseUser(response) {
     }
 }
 
+function parseUserBoard(response) {
+    var data = processResponse(response);
+    //console.log("USER: " + JSON.stringify(data))
+    data.leaderboard.items.forEach(function(ranking) {
+        if (ranking.user.relationship == "self")
+            userDetails.userLeadersboardRank = ranking.rank;
+        userDetails.boardModel.append({
+               "user": "#" + ranking.rank + ". " +makeUserName(ranking.user),
+               "shout": "<b>"+ranking.scores.recent+" "+"points" + "</b> " + ranking.scores.checkinsCount + " " + "checkins",
+               //"createdAt": "asdfasdf",
+               "photo": thumbnailPhoto(ranking.user.photo,100),
+        });
+        if(ranking.user.relationship=="self") {
+            leaderBoard.rank = ranking.rank;
+        }
+    });
+}
+
 function addPhoto(checkinID, venueID, photopath, makepublic, facebook, twitter) {
-    waiting.state = "shown";
+    waiting.show();
     var url = "https://api.foursquare.com/v2/photos/add?";
     if (checkinID!="") {
         url += "checkinId=" + checkinID;
@@ -709,14 +744,14 @@ function addPhoto(checkinID, venueID, photopath, makepublic, facebook, twitter)
 }
 
 function parseAddPhoto(response) {
-    waiting.state = "hidden";
+    waiting.hide();
     var photo = processResponse(response).photo;    
-    //console.log("ADDED PHOTO: " + JSON.stringify(photo));
-    if (photoAddDialog.checkinID!="") {
+    console.log("ADDED PHOTO: " + JSON.stringify(photo));
+    if (photoAdd.checkinID!="") {
         checkinDetails.photosBox.photosModel.insert(0,
                     makePhoto(photo,300));
     }
-    if (photoAddDialog.venueID!="") {
+    if (photoAdd.venueID!="") {
         venueDetails.photosBox.photosModel.insert(0,
                     makePhoto(photo,300));
     }
@@ -724,7 +759,7 @@ function parseAddPhoto(response) {
 
 function loadPhoto(photoid) {
     var url = "photos/" + photoid + "?" + getAccessTokenParameter();
-    waiting.state = "shown";
+    waiting.show();
     doWebRequest("GET", url, "", parsePhoto);
 }
 
@@ -732,19 +767,19 @@ function parsePhoto(response) {
     var photo = processResponse(response).photo;
     //console.log("PHOTO: " + JSON.stringify(photo))
 
-    photoDetails.photoUrl = photo.url;
+    photoDetails.photoUrl = thumbnailPhoto(photo);
     photoDetails.owner.userID = photo.user.id;
     photoDetails.owner.userName = "<span style='color:#000'>Uploaded by </span>" + makeUserName(photo.user);
-    photoDetails.owner.userPhoto.photoUrl = photo.user.photo;
+    photoDetails.owner.userPhoto.photoUrl = thumbnailPhoto(photo.user.photo,100);
     photoDetails.owner.userShout = "via " + parse(photo.source.name);
     photoDetails.owner.createdAt = makeTime(photo.createdAt);
 
-    waiting.state = "hidden";
+    waiting.hide();
 }
 
 function loadNotifications() {
     var url = "updates/notifications?" + getAccessTokenParameter();
-    waiting.state = "shown";
+    waiting.show();
     doWebRequest("GET",url,"", parseNotifications);
 }
 
@@ -759,7 +794,7 @@ function markNotificationsRead(time) {
 function parseNotifications(response) {
     var notis = processResponse(response).notifications;
     //console.log("NOTIFICATIONS: " + JSON.stringify(notis));
-    waiting.state = "hidden";
+    waiting.hide();
     notis.items.forEach(function(noti) {
         //console.log("NOTIFICATIONS: " + JSON.stringify(noti));
         var objectID = noti.target.object.id;
